package com.muyu.goods.controller;

import com.business.common.Select.BreakdownSel;
import com.business.common.domain.Breakdown;
import com.business.common.domain.FaultCode;
import com.business.common.domain.Sources;
import com.business.common.psvm.FaultInfo;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.core.web.page.TableDataInfo;
import com.muyu.goods.incident.mq.Producer;
import com.muyu.goods.service.IBreakdownService;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.Date;
import java.util.List;
import java.util.Map;

@RestController
@Log4j2
@RequestMapping("breakdown")
public class BreakdownController extends BaseController {
    @Autowired
    private IBreakdownService service;
    @Autowired
    private Producer producer;

    /**
     * 分页
     * @return
     */
    /**
     * 查询故障列表
     */
    @GetMapping("/list")
    public Result<TableDataInfo<Breakdown>> list( )
    {
        startPage();
        List<Breakdown> list = service.selectBreakdownList();
        return getDataTable(list);
    }

    @PostMapping("/lists")
    public Result<List<Breakdown>> lists() {
        List<Breakdown> list = service.lists();
        return success(list);
    }

    /**
     * 添加新的故障记录
     * @param breakdown
     * @return
     */
    @PostMapping("indexBreakDown")
    public Result indexBreakDown(@RequestBody Breakdown breakdown) {
        return success(service.indexBreakDown(breakdown));
    }

    /**
     * 故障解决记录
     * @param breakdown
     * @return
     */
    @PostMapping("updateBreakDown")
    public Result updateBreakDown(@RequestBody Breakdown breakdown) {
        return success(service.updateBreakDown(breakdown));
    }

    /**
     * 全部故障值
     * @return
     */
    @PostMapping("listFaultCode")
    public Result<List<FaultCode>> listFaultCode() {
        return success(service.listFaultCode());
    }

    @PostMapping("selectVinEnterprise/{vin}")
    public Result<Sources> selectVinEnterprise(@PathVariable String vin) {
        return success(service.selectVinEnterprise(vin));
    }

    /**
     * 图形化
     * @return
     */
    @PostMapping("pies")
    public Result<List<Map<String,Object>>> pies(@RequestBody BreakdownSel breakdownSel) {
        System.out.println(breakdownSel);
        return success(service.pies(breakdownSel));
    }

    /**
     * 测试队列
     */
    @PostMapping("start")
    public void start() {
        FaultInfo faultInfo = FaultInfo.builder()
                .faultCode("456")
                .vin("123")
                .time(new Date())
                .build();
        producer.start_time(faultInfo);
    }

    @PostMapping("end")
    public void end() {
        FaultInfo faultInfo = FaultInfo.builder()
                .faultCode("456")
                .vin("123")
                .time(new Date())
                .build();
        producer.end_time(faultInfo);
    }
}
