package com.muyu.goods.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.business.common.dev.LongitudeAndLatitude;
import com.business.common.domain.Car;
import com.business.common.domain.VehicleInfo;
import com.muyu.goods.service.ICarService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.page.TableDataInfo;

/**
 * 车辆信息Controller
 *
 * @author muyu
 * @date 2024-05-27
 */
@RestController
@RequestMapping("/car")
public class CarController extends BaseController
{
    @Autowired
    private ICarService carService;
    @Autowired
    private RedisTemplate<String,String> redisTemplate;

    /**
     * 查询车辆信息列表
     */
//    @RequiresPermissions("rule:car:list")
    @GetMapping("/list")
    public Result<TableDataInfo<Car>> list(Car car)
    {
        startPage();
        List<Car> list = carService.selectCarList(car);
        return getDataTable(list);
    }

    /**
     *
     * @return
     */
    @PostMapping("/lists")
    public Result<List<Car>> lists() {
        return success(carService.lists());
    }

    /**
     * 导出车辆信息列表
     */
//    @RequiresPermissions("rule:car:export")
    @Log(title = "车辆信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Car car)
    {
        List<Car> list = carService.selectCarList(car);
        ExcelUtil<Car> util = new ExcelUtil<Car>(Car.class);
        util.exportExcel(response, list, "车辆信息数据");
    }

    /**
     * 获取车辆信息详细信息
     */
//    @RequiresPermissions("rule:car:query")
    @GetMapping(value = "/{carId}")
    public Result getInfo(@PathVariable("carId") Long carId)
    {
        return success(carService.selectCarByCarId(carId));
    }

    @PostMapping("/query/{carId}")
    public Result query(@PathVariable("carId") Long carId){
        return success(carService.query(carId));
    }

    /**
     * 新增车辆信息
     */
//    @RequiresPermissions("rule:car:add")
    @Log(title = "车辆信息", businessType = BusinessType.INSERT)
    @PostMapping
    public Result add(@RequestBody Car car)
    {
        return toAjax(carService.insertCar(car));
    }

    /**
     * 修改车辆信息
     */
//    @RequiresPermissions("rule:car:edit")
    @Log(title = "车辆信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public Result edit(@RequestBody Car car)
    {
        return toAjax(carService.updateCar(car));
    }

    /**
     * 删除车辆信息
     */
//    @RequiresPermissions("rule:car:remove")
    @Log(title = "车辆信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{carIds}")
    public Result remove(@PathVariable Long[] carIds)
    {
        return toAjax(carService.deleteCarByCarIds(carIds));
    }

    /**
     * 启动实时数据事件
     * @return
     */
    @PostMapping("activate")
    public Result activate() {
        redisTemplate.opsForList();
        return null;
    }

    /**
     * 结束实时数据事件
     * @return
     */
    @PostMapping("finish")
    public Result finish() {
        String s = redisTemplate.opsForValue().get("01");
        return Result.success(s);
    }

    /**
     * 读取信息
     * @param
     * @return
     */
    @PostMapping("read")
    public Result<VehicleInfo> read() {
        return success(carService.read());
    }

    /**
     * 开启事件
     */
    @PostMapping("open")
    public void open() {
        carService.open();
    }

    /**
     * 结束事件
     */
    @PostMapping("close")
    public void close() {
        carService.close();
    }
}
