package com.muyu.goods.monitor.mq;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.business.common.domain.Breakdown;
import com.business.common.domain.VehicleInfo;
import com.business.common.psvm.FaultInfo;
import com.rabbitmq.client.Channel;

import com.muyu.goods.controller.BreakdownController;
import com.muyu.goods.service.impl.ExecuteService;
import lombok.Data;
import lombok.extern.log4j.Log4j2;
import org.springframework.amqp.core.AmqpAdmin;
import org.springframework.amqp.core.Message;
import org.springframework.amqp.core.ExchangeTypes;
import org.springframework.amqp.rabbit.annotation.Exchange;
import org.springframework.amqp.rabbit.annotation.Queue;
import org.springframework.amqp.rabbit.annotation.QueueBinding;
import org.springframework.amqp.rabbit.annotation.RabbitListener;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Component;

import java.io.IOException;
import java.util.Date;
import java.util.concurrent.TimeUnit;

@Component
@Log4j2
public class breakdownMqConsumer {
    @Autowired
    private AmqpAdmin amqpAdmin;
    @Autowired
    private ExecuteService executeService;
    @Autowired
    private BreakdownController breakdownController;
    @Autowired
    private RedisTemplate<String,String> redisTemplate;


    /**
     * 处理发生的故障
     * @param message
     */
//    @RabbitListener(queuesToDeclare = {@Queue("fault_start_message")})
//    监听交换机 Queue(队列名) @Exchange(value = "交换机名称", type = ExchangeTypes.FANOUT)

    @RabbitListener(bindings = {@QueueBinding(value = @Queue(name = "fault_start_message"),
            exchange = @Exchange(name = "fault.message", type = ExchangeTypes.DIRECT),
            key = { "start" })})
//    @RabbitListener(bindings = {@QueueBinding(value = @Queue("fault_start_message"),
//            exchange = @Exchange(value = "fault.message", type = ExchangeTypes.FANOUT))})
    public void failureOccurrence(String message, Channel channel, Message messageProperties) {
        String parse = JSON.parse(message).toString();
        FaultInfo faultInfo = JSON.parseObject(parse, FaultInfo.class);
        log.info("获取存在：{}",faultInfo);
        Breakdown breakdown = new Breakdown();
        breakdown.setFaultLevel(1);
        breakdown.setFaultStartTime(faultInfo.getTime());
        breakdown.setFaultCode(faultInfo.getFaultCode());
        breakdown.setVin(faultInfo.getVin());
        breakdown.setFaultState(0);
        System.out.println("取");
        executeService.indexBreakdown(breakdown);
        redisTemplate.opsForValue().set("vin",faultInfo.getVin(),10,TimeUnit.MINUTES);
        executeService.selectVinEnterprise();
        // 消费成功 手动确认
        try {
            channel.basicAck(messageProperties.getMessageProperties().getDeliveryTag(),false);
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
        // 在这里处理接收到的消息
    }

    /**
     * 处理解决的故障
     * @param message
     */
//    @RabbitListener(queuesToDeclare = {@Queue("fault_end_message")})

    @RabbitListener(bindings = {@QueueBinding(value = @Queue(name = "fault_end_message"),
            exchange = @Exchange(name = "fault.message", type = ExchangeTypes.DIRECT),
            key = { "end" })})
//    @RabbitListener(bindings = {@QueueBinding(value = @Queue("fault_end_message"),
//            exchange = @Exchange(value = "fault.message", type = ExchangeTypes.FANOUT))})
    public void failureShooting(String message, Channel channel, Message messageProperties) {
        String parse = JSON.parse(message).toString();
        FaultInfo faultInfo = JSON.parseObject(parse, FaultInfo.class);
        log.info("解决:{}",message);
        Breakdown breakdown = new Breakdown();
        breakdown.setFaultEndTime(faultInfo.getTime());
        breakdown.setFaultCode(faultInfo.getFaultCode());
        breakdown.setVin(faultInfo.getVin());
        breakdown.setFaultState(1);
        System.out.println("改");
        breakdownController.updateBreakDown(breakdown);
        // 消费成功 手动确认
        try {
            channel.basicAck(messageProperties.getMessageProperties().getDeliveryTag(),false);
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
        // 在这里处理接收到的消息
    }
}
