package com.muyu.goods.service.impl;

import java.util.List;
import java.util.UUID;
import java.util.concurrent.TimeUnit;
import java.util.stream.Collectors;

import com.alibaba.fastjson.JSON;
import com.business.common.dev.*;
import com.business.common.domain.*;
import com.business.common.pojo.HttpCar;
import com.muyu.goods.client.ManageApi;
import com.muyu.goods.mapper.CarMapper;
import com.muyu.goods.mapper.MapMapper;
import com.muyu.goods.service.ICarService;
import com.muyu.goods.timer.Timer;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;

/**
 * 车辆信息Service业务层处理
 *
 * @author muyu
 * @date 2024-05-27
 */
@Service
@Log4j2
public class CarServiceImpl implements ICarService
{
    @Autowired
    private CarMapper carMapper;
    @Autowired
    private BusinessServiceImpl businessService;
    @Autowired
    private MapMapper mapMapper;
    @Autowired
    private RedisTemplate<String,String> redisTemplate;
    @Resource
    private ExecuteService service;

    /**
     * 查询车辆信息
     *
     * @param carId 车辆信息主键
     * @return 车辆信息
     */
    @Override
    public Car selectCarByCarId(Long carId)
    {
        return carMapper.selectCarByCarId(carId);
    }

    @Override
    public List<Car> lists() {
        return carMapper.lists();
    }

    /**
     * 查询车辆信息列表
     *
     * @param car 车辆信息
     * @return 车辆信息
     */
    @Override
    public List<Car> selectCarList(Car car)
    {
        Enterprise enterprise = businessService.listEnterprise();
        List<Car> list = carMapper.selectCarList(car);
        if (enterprise == null){
            return list;
        }else {
            List<Car> carList = list.stream().filter(cars -> cars.getOwnerId().equals(enterprise.getId())).collect(Collectors.toList());
            return carList;
        }

    }

    /**
     * 新增车辆信息
     *
     * @param car 车辆信息
     * @return 结果
     */
    @Override
    public int insertCar(Car car)
    {
        Enterprise enterprise = businessService.listEnterprise();
        if (enterprise == null){
            return 0;
        }
        System.out.println(enterprise);
        car.setOwnerId(enterprise.getId());
        car.setVin(UUID.randomUUID().toString().replaceAll("-",""));
        int i = carMapper.insertCar(car);
        if (i>0) {
            Car car1 = carMapper.carByCar();
            service.indexGroupFence(car1);
        }
        return i;
    }

    /**
     * 修改车辆信息
     *
     * @param car 车辆信息
     * @return 结果
     */
    @Override
    public int updateCar(Car car)
    {
        return carMapper.updateCar(car);
    }

    /**
     * 批量删除车辆信息
     *
     * @param carIds 需要删除的车辆信息主键
     * @return 结果
     */
    @Override
    public int deleteCarByCarIds(Long[] carIds)
    {
        int i = carMapper.deleteCarByCarIds(carIds);
        if (i>0){
            for (Long carId : carIds) {
                service.deleteCarGroupFence(carId);
            }
        }
        return i;
    }

    /**
     * 删除车辆信息信息
     *
     * @param carId 车辆信息主键
     * @return 结果
     */
    @Override
    public int deleteCarByCarId(Long carId)
    {
        int i = carMapper.deleteCarByCarId(carId);
        if (i>0) {
            service.deleteCarGroupFence(carId);
        }
        return i;
    }

    @Override
    public Car query(Long carId) {
        return carMapper.query(carId);
    }

    @Autowired
    private Timer timer;

    @Override
    public VehicleInfo read() {
        String rightPopAndLeftPush = null;
        try {
            rightPopAndLeftPush = redisTemplate.opsForList().leftPop("event_handler:realtime_data:JAV0VJUJYOTOK9KSY"
                    , 3, TimeUnit.SECONDS);
            if (rightPopAndLeftPush != null) {
                log.info("处理消息: {}", rightPopAndLeftPush);
            }
        } catch (Exception e) {
            log.error(e.getMessage());
        }
        if (rightPopAndLeftPush != null){
            String parse = JSON.parse(rightPopAndLeftPush).toString();
            VehicleInfo vehicleInfo = JSON.parseObject(parse, VehicleInfo.class);
//            LongitudeAndLatitude longitudeAndLatitude = LongitudeAndLatitude.builder()
//                    .latitude(latitude)
//                    .longitude(longitude)
//                    .build();
            return vehicleInfo;
        }else{
            return null;
        }
    }

    @Autowired
    private ManageApi manageApi;

    @Override
    public void open() {
//        manageApi.open();
        HttpCar.http("open");

    }

    @Override
    public void close() {
        HttpCar.http("close");
//        manageApi.close();
    }


}
