package com.muyu.goods.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.business.common.dev.CarFenceGroupsDev;
import com.business.common.middle.CarFenceDev;
import com.business.common.middle.CarGroupsDev;
import com.business.common.middle.GroupFenceDev;
import com.business.common.domain.Fence;
import com.business.common.domain.FenceGroups;
import com.business.common.psvm.Pences;
import com.muyu.goods.mapper.MapMapper;
import com.muyu.goods.service.IMapService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.List;
import java.util.stream.Collectors;

@Service
public class MapService implements IMapService {
    @Autowired
    private MapMapper mapMapper;

    /**
     * 围栏组
     * @return
     */
    @Override
    public List<FenceGroups> selectFenceGroups() {
        List<FenceGroups> fenceGroupsList = mapMapper.selectFenceGroups();
        return fenceGroupsList;
    }

    /**
     * 查看电子围栏
     * @return
     */
    @Override
    public List<Fence> selectFence() {
        List<Fence> fenceList = mapMapper.selectFence();
        return fenceList;
    }

    /**
     * 车辆绑定围栏组详情
     * @param carId
     * @return
     */
    @Override
    public List<List<GroupFenceDev>> selectFenceGroupsById(Long carId) {
        List<CarGroupsDev> carGroupsDevs = selectCarGroups();
        List<CarGroupsDev> carGroupsDevList = carGroupsDevs.stream().filter(group -> group.getCarId() == carId).collect(Collectors.toList());
        List<List<GroupFenceDev>> listList = new ArrayList<>();
        List<GroupFenceDev> groupFenceDevs = selectGroupFence();
        for (CarGroupsDev carGroupsDev : carGroupsDevList) {
            List<GroupFenceDev> groupFenceDevList = groupFenceDevs.stream().filter(group -> group.getGroupsId() == carGroupsDev.getGroupsId()).collect(Collectors.toList());
            listList.add(groupFenceDevList);
        }
        return listList;
    }

    /**
     * 传入电子围栏
     * @param pences
     * @return
     */
    @Override
    public String getSel(Pences pences) {
        System.out.println(pences);
        return JSONObject.toJSONString(pences);
    }

    /**
     * 删除电子围栏
     * @param fenceId
     * @return
     */
    @Override
    public String deleteFence(Long fenceId) {
        int i = mapMapper.deleteFence(fenceId);
        if (i>0){
            return "完成";
        }
        return "无效";
    }

    /**
     * 电子围栏详情
     * @param fenceId
     * @return
     */
    @Override
    public Fence queryFence(Long fenceId) {
        return mapMapper.queryFence(fenceId);
    }

    /**
     * 修改电子围栏状态
     * @param fenceId
     * @return
     */
    @Override
    public String updateFence(Long fenceId) {
        Fence fence = queryFence(fenceId);
        int i = 0;
        if (fence.getStaut().equals("Y")){
            i = mapMapper.updateFence(fenceId,"N");
        }else {
            i = mapMapper.updateFence(fenceId,"Y");
        }
        if (i>0){
            return "成功";
        }
        return "失败";
    }

    /**
     * 车辆与电子围栏
     * @return
     */
    @Override
    public List<CarFenceDev> selectCarFence() {
        return mapMapper.selectCarFence();
    }

    /**
     * 车辆与围栏组
     * @return
     */
    @Override
    public List<CarGroupsDev> selectCarGroups() {
        return mapMapper.selectCarGroups();
    }

    /**
     * 围栏组与电子围栏
     * @return
     */
    @Override
    public List<GroupFenceDev> selectGroupFence() {
        return mapMapper.selectGroupFence();
    }

    @Override
    @Transactional
    public String indexGroups(CarFenceGroupsDev carFenceGroupsDev) {
        int i = mapMapper.indexGroups(carFenceGroupsDev);
        if (i>0) {
            FenceGroups fenceGroups1 = mapMapper.selectFenceGroupsByOne();
            mapMapper.indexCarGroupsDev(carFenceGroupsDev.getCarId(),fenceGroups1.getGroupsId());
            return "成功";
        }
        return "失败";
    }
}
