package com.muyu.goods.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.muyu.common.system.domain.SysUser;
import com.muyu.goods.domain.Custom;
import com.muyu.goods.domain.Enterprise;
import com.muyu.goods.domain.Sources;
import com.muyu.goods.mq.Producer;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.goods.service.IEnterpriseService;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.page.TableDataInfo;

/**
 * 企业Controller
 *
 * @author muyu
 * @date 2024-05-26
 */
@RestController
@RequestMapping("/enterprise")
public class EnterpriseController extends BaseController
{
    @Autowired
    private IEnterpriseService enterpriseService;


    @PostMapping("rest")
    public void send() {
        enterpriseService.send();
    }

    /**
     * 查询企业列表
     */
//    @RequiresPermissions("goods:enterprise:list")
    @GetMapping("/list")
    public Result<TableDataInfo<Enterprise>> list(Enterprise enterprise)
    {
        startPage();
        List<Enterprise> list = enterpriseService.selectEnterpriseList(enterprise);
        return getDataTable(list);
    }

    /**
     * 企业详情
     * @return
     */
    @PostMapping("lists")
    public Result<List<Enterprise>> lists(){
        return success(enterpriseService.lists());
    }

    /**
     * 导出企业列表
     */
//    @RequiresPermissions("goods:enterprise:export")
    @Log(title = "企业", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Enterprise enterprise)
    {
        List<Enterprise> list = enterpriseService.selectEnterpriseList(enterprise);
        ExcelUtil<Enterprise> util = new ExcelUtil<Enterprise>(Enterprise.class);
        util.exportExcel(response, list, "企业数据");
    }

    /**
     * 获取企业详细信息
     */
//    @RequiresPermissions("goods:enterprise:query")
    @GetMapping(value = "/{id}")
    public Result<Enterprise> getInfo(@PathVariable("id") Long id)
    {
        return success(enterpriseService.selectEnterpriseById(id));
    }

    @PostMapping("getEnterpriseById")
    public Result<Enterprise> getEnterpriseById(Long id) {
        return success(enterpriseService.getEnterpriseById(id));
    }

    /**
     * 新增企业
     */
    @RequiresPermissions("goods:enterprise:add")
    @Log(title = "企业", businessType = BusinessType.INSERT)
    @PostMapping
    public Result add(@RequestBody Enterprise enterprise) throws IOException, InterruptedException {
        return toAjax(enterpriseService.insertEnterprise(enterprise));
    }

    /**
     * 修改企业
     */
//    @RequiresPermissions("goods:enterprise:edit")
    @Log(title = "企业", businessType = BusinessType.UPDATE)
    @PutMapping
    public Result edit(@RequestBody Enterprise enterprise)
    {
        return toAjax(enterpriseService.updateEnterprise(enterprise));
    }

    /**
     * 判断公司名称是否唯一
     * @param enterpriseName
     * @return
     */
    @PostMapping("oneName")
    public Result oneName(String enterpriseName) {
        return success(enterpriseService.oneName(enterpriseName));
    }

    /**
     * 判断联系方式是否唯一
     * @param contactPhone
     * @return
     */
    @PostMapping("onePhone")
    public Result onePhone(@RequestParam String contactPhone) {
        return success(enterpriseService.onePhone(contactPhone));
    }

    /**
     * 判断邮箱是否唯一
     * @param email
     * @return
     */
    @PostMapping("oneEmail")
    public Result oneEmail(@RequestParam String email) {
        return success(enterpriseService.oneEmail(email));
    }

    /**
     * 企业认证
     * @param id
     * @return
     */
    @PostMapping("authentication")
    public Result authentication(Long id){
        return toAjax(enterpriseService.authentication(id));
    }

    /**
     * 删除企业
     */
//    @RequiresPermissions("goods:enterprise:remove")
    @Log(title = "企业", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public Result remove(@PathVariable Long[] ids)
    {
        return toAjax(enterpriseService.deleteEnterpriseByIds(ids));
    }

    /**
     * 获取企业管理账户
     * @return
     */
    @PostMapping("sysUsers")
    public Result<List<SysUser>> sysUsers() {
        return success(enterpriseService.sysUsers());
    }

    /**
     * 增值服务
     * @param id
     * @param serviceLevel
     * @return
     */
    @PostMapping("getLevel")
    public Result getLevel(Long id,Integer serviceLevel){
        return success(enterpriseService.getLevel(id,serviceLevel));
    }

    @PostMapping("bu/{id}")
    public Result bu(@PathVariable Long id){
        return success(enterpriseService.bu(id));
    }

    /**
     * 企业服务信息
     * @return
     */
    @PostMapping("/listSources")
    public Result<List<Sources>> listSources() {
        return success(enterpriseService.listSources());
    }

    /**
     * 申请定制服务
     * @param custom
     * @return
     */
    @PostMapping("/indexCustom")
    public Result indexCustom(@RequestBody Custom custom) {
        return success(enterpriseService.indexCustom(custom));
    }

    /**
     * 查看所有定制服务
     * @return
     */
    @PostMapping("listCustom")
    public Result<List<Custom>> listCustom() {
        return success(enterpriseService.listCustom());
    }

}
