package com.muyu.goods.service;

import java.io.IOException;
import java.util.List;

import com.muyu.common.system.domain.SysUser;
import com.muyu.goods.domain.Custom;
import com.muyu.goods.domain.Enterprise;
import com.muyu.goods.domain.Sources;

/**
 * 企业Service接口
 *
 * @author muyu
 * @date 2024-05-26
 */
public interface IEnterpriseService
{
    /**
     * 查询企业
     *
     * @param id 企业主键
     * @return 企业
     */
    public Enterprise selectEnterpriseById(Long id);

    /**
     * 查询企业列表
     *
     * @param enterprise 企业
     * @return 企业集合
     */
    public List<Enterprise> selectEnterpriseList(Enterprise enterprise);

    /**
     * 新增企业
     *
     * @param enterprise 企业
     * @return 结果
     */
    public int insertEnterprise(Enterprise enterprise) throws IOException, InterruptedException;

    /**
     * 修改企业
     *
     * @param enterprise 企业
     * @return 结果
     */
    public int updateEnterprise(Enterprise enterprise);

    /**
     * 判断唯一
     */
    Integer oneName(String enterpriseName);

    Integer onePhone(String contactPhone);

    Integer oneEmail(String email);

    /**
     * 企业认证
     * @param id
     * @return
     */
    int authentication(Long id);

    /**
     * 批量删除企业
     *
     * @param ids 需要删除的企业主键集合
     * @return 结果
     */
    public int deleteEnterpriseByIds(Long[] ids);

    /**
     * 删除企业信息
     *
     * @param id 企业主键
     * @return 结果
     */
    public int deleteEnterpriseById(Long id);


    Enterprise getEnterpriseById(Long id);

    List<SysUser> sysUsers();

    List<Enterprise> lists();

    String getLevel(Long id, Integer serviceLevel);

    String bu(Long id);

    List<Sources> listSources();

    int indexCustom(Custom custom);

    List<Custom> listCustom();

    void send();
}
