package com.muyu.goods.service.impl;

import java.io.IOException;
import java.util.List;
import java.util.UUID;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.muyu.common.core.utils.DateUtils;
import com.muyu.common.security.utils.SecurityUtils;
import com.muyu.common.system.domain.LoginUser;
import com.muyu.common.system.domain.SysUser;
import com.muyu.common.system.remote.RemoteUserService;
import com.muyu.goods.domain.Custom;
import com.muyu.goods.domain.Sources;
import com.muyu.goods.mq.Producer;
import com.muyu.goods.pojo.HttpClient;
import muyu.goods.enterprise.client.config.EnterpriseConfig;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Service;
import com.muyu.goods.mapper.EnterpriseMapper;
import com.muyu.goods.domain.Enterprise;
import com.muyu.goods.service.IEnterpriseService;

/**
 * 企业Service业务层处理
 *
 * @author muyu
 * @date 2024-05-26
 */
@Service
public class EnterpriseServiceImpl implements IEnterpriseService
{
    @Autowired
    private EnterpriseMapper enterpriseMapper;
    @Autowired
    private EnterpriseConfig enterpriseConfig;
    @Autowired
    private Producer producer;
    @Autowired
    private RedisTemplate<String,String> redisTemplate;

    /**
     * 查询企业
     *
     * @param id 企业主键
     * @return 企业
     */
    @Override
    public Enterprise selectEnterpriseById(Long id)
    {
        return enterpriseMapper.selectEnterpriseById(id);
    }

    /**
     * 查询企业列表
     *
     * @param enterprise 企业
     * @return 企业
     */
    @Override
    public List<Enterprise> selectEnterpriseList(Enterprise enterprise)
    {
        List<Enterprise> enterprises = enterpriseMapper.selectEnterpriseList(enterprise);
        return enterprises;
    }

    /**
     * 新增企业
     *
     * @param enterprise 企业
     * @return 结果
     */
    @Override
    public int insertEnterprise(Enterprise enterprise) throws IOException, InterruptedException {
        enterprise.setCreateTime(DateUtils.getNowDate());
        enterprise.setRegistrationDate(DateUtils.getNowDate());
        LoginUser loginUser = SecurityUtils.getLoginUser();
        enterprise.setCreateBy(loginUser.getUsername());
        enterprise.setBusinessLincenseNumber(UUID.randomUUID().toString().replaceAll("-",""));
        int i = enterpriseMapper.insertEnterprise(enterprise);
        if (i>0){
            Enterprise enterprise1 = enterpriseMapper.queryDateEnterprise();
            enterpriseConfig.index(enterprise1);
        }
        return i;
    }

    /**
     * 修改企业
     *
     * @param enterprise 企业
     * @return 结果
     */
    @Override
    public int updateEnterprise(Enterprise enterprise)
    {
        enterprise.setUpdateTime(DateUtils.getNowDate());
        LoginUser loginUser = SecurityUtils.getLoginUser();
        enterprise.setUpdateBy(loginUser.getUsername());
        return enterpriseMapper.updateEnterprise(enterprise);
    }

    @Override
    public Integer oneName(String enterpriseName) {
        return enterpriseMapper.oneName(enterpriseName);
    }

    @Override
    public Integer onePhone(String contactPhone) {
        return enterpriseMapper.onePhone(contactPhone);
    }

    @Override
    public Integer oneEmail(String email) {
        return enterpriseMapper.oneEmail(email);
    }

    /**
     * 企业认证
     * @param id
     * @return
     */
    @Override
    public int authentication(Long id) {
        Enterprise enterprise = new Enterprise();
        enterprise.setId(id);
        enterprise.setAuthenticationDate(DateUtils.getNowDate());
        int i = enterpriseMapper.authentication(enterprise);
        if (i>0) {
            Enterprise enterprise1 = selectEnterpriseById(id);
            //新建的企业绑定mysql服务
            try {
                HttpClient.http(enterprise1);
            } catch (IOException e) {
                throw new RuntimeException(e);
            } catch (InterruptedException e) {
                throw new RuntimeException(e);
            }
            Sources sources = Sources.index(enterprise1.getId(),"enterprise" + enterprise1.getId(), String.valueOf((int) (enterprise.getId() + 3306)));
            enterpriseMapper.indexSources(sources);
            producer.datasource(sources.getIp());
        }
        return i;
    }

    /**
     * 批量删除企业
     *
     * @param ids 需要删除的企业主键
     * @return 结果
     */
    @Override
    public int deleteEnterpriseByIds(Long[] ids)
    {
        return enterpriseMapper.deleteEnterpriseByIds(ids);
    }

    /**
     * 删除企业信息
     *
     * @param id 企业主键
     * @return 结果
     */
    @Override
    public int deleteEnterpriseById(Long id)
    {
        return enterpriseMapper.deleteEnterpriseById(id);
    }

    /**
     * 获取企业详情
     * @param id
     * @return
     */
    @Override
    public Enterprise getEnterpriseById(Long id) {
        return enterpriseMapper.getEnterpriseById(id);
    }

    /**
     * 获取和企业绑定的用户
     * @return
     */
    @Override
    public List<SysUser> sysUsers() {
        return enterpriseConfig.sysUsers();
    }

    /**
     * 获取全部企业详情
     * @return
     */
    @Override
    public List<Enterprise> lists() {
        List<Enterprise> enterprises = selectEnterpriseList(null);
        List<String> range = redisTemplate.opsForList().range("enterprises", 0, -1);
        System.out.println(range);
        return enterprises;
    }

    /**
     * 选择服务
     * @param id
     * @param serviceLevel
     * @return
     */
    @Override
    public String getLevel(Long id, Integer serviceLevel) {
        Integer i = enterpriseMapper.getLevel(id,serviceLevel);
        if (i>0){
            return "选择完成";
        }else{
            return "选择失败";
        }
    }

    @Override
    public String bu(Long id) {
        Enterprise enterprise = selectEnterpriseById(id);
        //补充企业绑定mysql服务
        try {
            HttpClient.http(enterprise);
        } catch (IOException e) {
            throw new RuntimeException(e);
        } catch (InterruptedException e) {
            throw new RuntimeException(e);
        }
        return "成功";
    }

    @Override
    public List<Sources> listSources() {
//        producer.datasource("3306");
        return enterpriseMapper.listSources(new QueryWrapper<>());
    }

    @Override
    public int indexCustom(Custom custom) {
        int i = enterpriseMapper.indexCustom(custom);
        return i;
    }

    @Override
    public List<Custom> listCustom() {
        return enterpriseMapper.listCustom();
    }

    @Override
    public void send() {
        List<Enterprise> lists = lists();
        String jsonString = JSONObject.toJSONString(lists);
        producer.vehicleEvent(jsonString);
    }

}
