package com.muyu.incident.client.config;

import com.alibaba.fastjson2.JSONObject;
import com.incident.server.model.IncidentModel;
import com.muyu.incident.common.config.MsgConfig;
import com.muyu.incident.common.constants.VehicleConstant;
import lombok.extern.log4j.Log4j2;
import org.springframework.amqp.core.*;
import org.springframework.amqp.rabbit.annotation.RabbitListener;
import org.springframework.amqp.rabbit.connection.CachingConnectionFactory;
import org.springframework.amqp.rabbit.connection.ConnectionFactory;
import org.springframework.amqp.rabbit.core.RabbitAdmin;
import org.springframework.amqp.rabbit.core.RabbitTemplate;
import org.springframework.amqp.rabbit.listener.SimpleMessageListenerContainer;
import org.springframework.amqp.rabbit.listener.api.ChannelAwareMessageListener;
import org.springframework.boot.autoconfigure.amqp.RabbitProperties;
import org.springframework.amqp.core.FanoutExchange;
import org.springframework.context.annotation.Bean;
import org.springframework.stereotype.Component;

import java.util.Arrays;


/**
 * 消息处理配置
 */
@Component
@Log4j2
public class MsgComponent {
    /**
     * 队列声明
     * @param kafkaConfig 名称依据
     * @return 队列对象
     */
    @Bean
    public Queue initCehicleEventClientQueue(KafkaConfig kafkaConfig) {
        return new Queue(kafkaConfig.queueName(),true,true,true);
    }

    /**
     * 绑定交换机
//     * @param vehicleEventExchange 交换机
     * @param initCehicleEventClientQueue 队列
     * @return 绑定结果
     */
    @Bean
    public Binding binding1(Queue initCehicleEventClientQueue) {
        MsgConfig msgConfig = new MsgConfig();
        FanoutExchange fanoutExchange = msgConfig.VehicleEvent();
        System.out.println(fanoutExchange);
        System.out.println(initCehicleEventClientQueue);
        return BindingBuilder.bind(initCehicleEventClientQueue).to(fanoutExchange);
    }

    /**
     * 自定义rabbitmq
     * @param connectionFactory
     * @param kafkaConfig
     * @return
     */
    @Bean
    public SimpleMessageListenerContainer messageListenerContainer(ConnectionFactory connectionFactory,KafkaConfig kafkaConfig) {
        SimpleMessageListenerContainer simpleMessageListenerContainer = new SimpleMessageListenerContainer(connectionFactory);
        //针对哪些队列（参数为可变参数）
        simpleMessageListenerContainer.setQueueNames(kafkaConfig.queueName());
        //同时有多少个消费者线程在消费这个队列，相当于线程池的线程数字。
        simpleMessageListenerContainer.setConcurrentConsumers(3);
        //最大的消费者线程数
        simpleMessageListenerContainer.setMaxConcurrentConsumers(5);
        //设置消息确认方式    NONE=不确认,MANUAL=手动确认,AUTO=自动确认;
        //自动确认
        simpleMessageListenerContainer.setAcknowledgeMode(AcknowledgeMode.AUTO);
//        simpleMessageListenerContainer.setMessageListener(message -> log.info("springboot.rabbitmq-queue接收到的消息：[{}]", message.toString()));
        //手动确认(单条确认)
        simpleMessageListenerContainer.setAcknowledgeMode(AcknowledgeMode.MANUAL);
        simpleMessageListenerContainer.setMessageListener((ChannelAwareMessageListener) (message, channel) -> {
            log.info("springboot.rabbitmq-queue接收到的消息：[{}]",
                    JSONObject.parseObject(new String(message.getBody()), IncidentModel.class)
                    );
                channel.basicAck(message.getMessageProperties().getDeliveryTag(), false);
        });
        //消费端限流
        simpleMessageListenerContainer.setPrefetchCount(1);
        return simpleMessageListenerContainer;
    }

    @Bean
    public ConnectionFactory connectionFactory(RabbitProperties rabbitProperties) {
        CachingConnectionFactory cachingConnectionFactory = new CachingConnectionFactory();
        cachingConnectionFactory.setHost(rabbitProperties.getHost());
        cachingConnectionFactory.setPort(rabbitProperties.getPort());
        cachingConnectionFactory.setUsername(rabbitProperties.getUsername());
        cachingConnectionFactory.setPassword(rabbitProperties.getPassword());
        //开启发送确认
        cachingConnectionFactory.setPublisherConfirmType(CachingConnectionFactory.ConfirmType.CORRELATED);
        //开启消息返回
        cachingConnectionFactory.setPublisherReturns(true);
        cachingConnectionFactory.createConnection();
        return cachingConnectionFactory;
    }
    @Bean
    public RabbitAdmin rabbitAdmin(ConnectionFactory connectionFactory) {
        RabbitAdmin rabbitAdmin = new RabbitAdmin(connectionFactory);
        rabbitAdmin.setAutoStartup(true);
        return rabbitAdmin;
    }

    @Bean
    public RabbitTemplate rabbitTemplate(ConnectionFactory connectionFactory) {
        RabbitTemplate rabbitTemplate = new RabbitTemplate(connectionFactory);
        rabbitTemplate.setMandatory(true);
        //消息返回
        rabbitTemplate.setReturnCallback((message, i, s, s1, s2) -> {
            log.info("消息返回实现，message：{},replyCode：{},replyText：{},exchange：{},routingKey：{}", message, i, s, s1, s2);
        });
        //发送端确认
        rabbitTemplate.setConfirmCallback((correlationData, b, s) -> {
            log.info("发送端确认，correlationData：{},ack：{},cause：{}", correlationData, b, s);
        });
        return rabbitTemplate;
    }


}
