package com.muyu.cloud.datasource.config;

import com.alibaba.druid.pool.DruidDataSource;
import com.muyu.cloud.datasource.config.contents.DataSourceInfo;
import com.muyu.common.core.domain.Result;
import com.muyu.common.goods.domain.Sources;
import com.muyu.common.goods.remote.RemoteSourcesService;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.annotation.Primary;

import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author DongZl
 * @description: 数据源配置
 * @Date 2023-8-1 上午 11:05
 */
@Log4j2
@Configuration
public class DruidConfig {
    @Autowired
    private RemoteSourcesService remoteSourcesService;
    /**
     * 获取多数据源信息列表
     * @return
     */
    private List<DataSourceInfo> getDataSourceInfoList(){
        List<Sources> listResult = remoteSourcesService.listSources().getData();
        System.out.println(listResult);
        List<String> databaseNameList = new ArrayList<>();
        databaseNameList.add("3306");
        listResult.forEach(res -> {
            databaseNameList.add(res.getIp());
        });
//        List<String> databaseNameList = new ArrayList<>(){{
//            add("3310");
//            add("3311");
//        }};
        System.out.println(databaseNameList);
        List<DataSourceInfo> list = databaseNameList.stream().map(DataSourceInfo::dataIpBuild).toList();
        return list;
    }

    /**
     * @Description: 根据传递的数据源信息测试数据库连接
     * @Author Dongzl
     */
    public DruidDataSource createDataSourceConnection(DataSourceInfo dataSourceInfo) {
        DruidDataSource druidDataSource = new DruidDataSource();
        druidDataSource.setUrl(dataSourceInfo.getUrl());
        druidDataSource.setUsername(dataSourceInfo.getUserName());
        druidDataSource.setPassword(dataSourceInfo.getPassword());
        druidDataSource.setBreakAfterAcquireFailure(true);
        druidDataSource.setConnectionErrorRetryAttempts(0);
        try {
            druidDataSource.getConnection(2000);
            log.info("{} -> 数据源连接成功", dataSourceInfo.getIp());
            return druidDataSource;
        } catch (SQLException throwables) {
            log.error("数据源 {} 连接失败,用户名：{}，密码 {}",dataSourceInfo.getUrl(),dataSourceInfo.getUserName(),dataSourceInfo.getPassword());
            return null;
        }
    }

    /**
     * 动态操作数据源
     * @param
     * @return
     */
    @Bean
    @Primary
    public DynamicDataSource dynamicDataSource() {
        //获取列表 获取多数据源信息
        Map<Object, Object> dataSourceMap = new HashMap<>();
        getDataSourceInfoList().forEach(dataSourceInfo -> {
            dataSourceMap.put(dataSourceInfo.getIp(), createDataSourceConnection(dataSourceInfo));
        });
        System.out.println(getDataSourceInfoList());
//        System.out.println(dataSourceMap);
        //设置动态数据源
        DynamicDataSource dynamicDataSource = new DynamicDataSource();
//        dynamicDataSource.setDefaultTargetDataSource(dynamicDataSource);
        dynamicDataSource.setTargetDataSources(dataSourceMap);
        //将数据源信息备份在defineTargetDataSources中
        dynamicDataSource.setDefineTargetDataSources(dataSourceMap);
        return dynamicDataSource;
    }
}
