package com.muyu.cloud.datasource.config;

import com.alibaba.druid.pool.DruidDataSource;
import com.muyu.cloud.datasource.DynamicDataSourceHolder;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.springframework.jdbc.datasource.lookup.AbstractRoutingDataSource;

import java.util.Map;

/**
 * 动态数据源
 * 多数据源规则
 * 调用AddDefineDataSource组件的addDefineDynamicDataSource（）方法，获取原来targetdatasources的map，并将新的数据源信息添加到map中，并替换targetdatasources中的map
 * 切换数据源时可以使用@DataSource(value = "数据源名称")，或者DynamicDataSourceContextHolder.setContextKey("数据源名称")
 * @author Dongzl
 */
@Data
@AllArgsConstructor
@NoArgsConstructor
public class DynamicDataSource extends AbstractRoutingDataSource {
    //备份所有数据源信息 主要是指针，
    private Map<Object, Object> defineTargetDataSources;

    /**
     * 判定建是否出站
     * @param key
     * @return 在 true 否false
     */
    public boolean hashKey(String key) {
        return defineTargetDataSources.containsKey(key);
    }

    /**
     * 增加新的数据源
     * @param key
     * @param value
     */
    public void put(String key, DruidDataSource value){
        defineTargetDataSources.put(key,value);
    }

    /**
     * 决定当前线程使用哪个数据源
     */
    @Override
    protected Object determineCurrentLookupKey() {
        return DynamicDataSourceHolder.getDynamicDataSourceKey();
    }
}
