package com.muyu.cloud.datasource.interceptor;

import com.muyu.cloud.datasource.DynamicDataSourceHolder;
import com.muyu.cloud.datasource.config.DynamicDataSource;
import com.muyu.cloud.datasource.exception.SaasException;
import com.muyu.cloud.datasource.config.contents.SaasConstant;
import com.muyu.common.core.utils.ServletUtils;
import com.muyu.common.core.utils.SpringUtils;
import org.springframework.web.method.HandlerMethod;
import org.springframework.web.servlet.AsyncHandlerInterceptor;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

/**
 * 拦截器
 */
public class DataScopeInterceptor implements AsyncHandlerInterceptor{// 继承头部拦截

    /**
     * 之前
     */
    @Override
    public boolean preHandle(HttpServletRequest request, HttpServletResponse response, Object handler) throws Exception {
        //进行跨域检测
        if (!(handler instanceof HandlerMethod)){
            return true;
        }
        // 获取请求头
        String header = ServletUtils.getHeader(request, SaasConstant.SAAS_KEY);
        if (header == null) {
            throw new SaasException("saas非法访问");//提交异常
        }else {
            DynamicDataSource dynamicDataSource = SpringUtils.getBean(DynamicDataSource.class);
            if (!dynamicDataSource.hashKey(header)){//判定是否出站
                throw new SaasException("saas非法访问");
            }
        }
        DynamicDataSourceHolder.setDynamicDataSourceKey(header);
        return true;//默认返回true
    }

    /**
     * 之后
     */
    @Override
    public void afterConcurrentHandlingStarted(HttpServletRequest request, HttpServletResponse response, Object handler) throws Exception {
        //用于清空
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
    }


}
